@@ -3,13 +3,13 @@ build_time_vars = {'ABIFLAGS': '',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
- 'ALIGNOF_LONG': 8,
- 'ALIGNOF_SIZE_T': 8,
+ 'ALIGNOF_LONG': 4,
+ 'ALIGNOF_SIZE_T': 4,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
  'AR': 'ar',
  'ARFLAGS': 'rcs',
- 'BASECFLAGS': '-Wno-unused-result -Wsign-compare -mieee',
+ 'BASECFLAGS': '-Wno-unused-result -Wsign-compare',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/pkg/bin',
@@ -21,19 +21,19 @@ build_time_vars = {'ABIFLAGS': '',
               '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'alpha--netbsd',
+ 'BUILD_GNU_TYPE': 'sparc--netbsdelf',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-Wno-unused-result -Wsign-compare -mieee -DNDEBUG -O2 -mieee '
-           '-I/usr/include -I/usr/pkg/include -O2 -mieee -I/usr/include '
-           '-I/usr/pkg/include -O2 -mieee -I/usr/include -I/usr/pkg/include',
+ 'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -I/usr/include '
+           '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include -O2 '
+           '-I/usr/include -I/usr/pkg/include',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-O2 -mieee -I/usr/include -I/usr/pkg/include',
+ 'CONFIGURE_CFLAGS': '-O2 -I/usr/include -I/usr/pkg/include',
  'CONFIGURE_CFLAGS_NODIST': '-std=gnu99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
@@ -48,22 +48,21 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-readline=readline' '--with-system-expat' "
                 "'--with-system-ffi' '--without-ensurepip' "
                 "'--without-pymalloc' '--prefix=/usr/pkg' "
-                "'--build=alpha--netbsd' '--host=alpha--netbsd' "
+                "'--build=sparc--netbsdelf' '--host=sparc--netbsdelf' "
                 "'--mandir=/usr/pkg/man' '--enable-option-checking=yes' "
-                "'build_alias=alpha--netbsd' 'host_alias=alpha--netbsd' "
-                "'CC=gcc' 'CFLAGS=-O2 -mieee -I/usr/include "
-                "-I/usr/pkg/include' 'LDFLAGS=-L/usr/lib -Wl,-R/usr/lib "
-                '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
-                "-Wl,-R/usr/X11R7/lib' 'LIBS=' 'CPPFLAGS=-I/usr/include "
-                "-I/usr/pkg/include' "
-                "'PKG_CONFIG=/tmp/pkgbuild/lang/python310/work.alpha/.tools/bin/pkg-config' "
+                "'build_alias=sparc--netbsdelf' 'host_alias=sparc--netbsdelf' "
+                "'CC=gcc' 'CFLAGS=-O2 -I/usr/include -I/usr/pkg/include' "
+                "'LDFLAGS=-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib "
+                "-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib' "
+                "'LIBS=' 'CPPFLAGS=-I/usr/include -I/usr/pkg/include' "
+                "'PKG_CONFIG=/tmp/pkgbuild/lang/python310/work.sparc/.tools/bin/pkg-config' "
                 "'PKG_CONFIG_PATH=' "
-                "'PKG_CONFIG_LIBDIR=/tmp/pkgbuild/lang/python310/work.alpha/.buildlink/lib/pkgconfig:/tmp/pkgbuild/lang/python310/work.alpha/.buildlink/share/pkgconfig'",
+                "'PKG_CONFIG_LIBDIR=/tmp/pkgbuild/lang/python310/work.sparc/.buildlink/lib/pkgconfig:/tmp/pkgbuild/lang/python310/work.sparc/.buildlink/share/pkgconfig'",
  'CONFINCLUDEDIR': '/usr/pkg/include',
  'CONFINCLUDEPY': '/usr/pkg/include/python3.10',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/tmp/pkgbuild/lang/python310/work.alpha/Python-3.10.14/coverage.info',
- 'COVERAGE_REPORT': '/tmp/pkgbuild/lang/python310/work.alpha/Python-3.10.14/lcov-report',
+ 'COVERAGE_INFO': '/tmp/pkgbuild/lang/python310/work.sparc/Python-3.10.15/coverage.info',
+ 'COVERAGE_REPORT': '/tmp/pkgbuild/lang/python310/work.sparc/Python-3.10.15/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include -I/usr/include '
@@ -84,8 +83,8 @@ build_time_vars = {'ABIFLAGS': '',
  'DLINCLDIR': '.',
  'DLLLIBRARY': '',
  'DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754': 0,
- 'DOUBLE_IS_BIG_ENDIAN_IEEE754': 0,
- 'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 1,
+ 'DOUBLE_IS_BIG_ENDIAN_IEEE754': 1,
+ 'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 0,
  'DTRACE': '',
  'DTRACE_DEPS': '\\',
  'DTRACE_HEADERS': '',
@@ -102,7 +101,7 @@ build_time_vars = {'ABIFLAGS': '',
  'EXTRA_CFLAGS': '',
  'EXT_SUFFIX': '.so',
  'FILEMODE': 644,
- 'FLOAT_WORDS_BIGENDIAN': 0,
+ 'FLOAT_WORDS_BIGENDIAN': 1,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
  'GITBRANCH': '',
@@ -229,7 +228,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GCC_ASM_FOR_MC68881': 0,
  'HAVE_GCC_ASM_FOR_X64': 0,
  'HAVE_GCC_ASM_FOR_X87': 0,
- 'HAVE_GCC_UINT128_T': 1,
+ 'HAVE_GCC_UINT128_T': 0,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETC_UNLOCKED': 1,
  'HAVE_GETENTROPY': 1,
@@ -280,7 +279,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_KILLPG': 1,
  'HAVE_KQUEUE': 1,
  'HAVE_LANGINFO_H': 1,
- 'HAVE_LARGEFILE_SUPPORT': 0,
+ 'HAVE_LARGEFILE_SUPPORT': 1,
  'HAVE_LCHFLAGS': 1,
  'HAVE_LCHMOD': 1,
  'HAVE_LCHOWN': 1,
@@ -541,7 +540,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_WRITEV': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'alpha--netbsd',
+ 'HOST_GNU_TYPE': 'sparc--netbsdelf',
  'INCLDIRSTOMAKE': '/usr/pkg/include /usr/pkg/include '
                    '/usr/pkg/include/python3.10 /usr/pkg/include/python3.10',
  'INCLUDEDIR': '/usr/pkg/include',
@@ -630,7 +629,7 @@ build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_LDFLAGS': '-L/usr/lib',
  'OPENSSL_LIBS': '-lssl -lcrypto',
  'OPENSSL_RPATH': '',
- 'OPT': '-DNDEBUG -O2 -mieee -I/usr/include -I/usr/pkg/include',
+ 'OPT': '-DNDEBUG -O2 -I/usr/include -I/usr/pkg/include',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -664,32 +663,30 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -mieee '
-                             '-DNDEBUG -O2 -mieee -I/usr/include '
-                             '-I/usr/pkg/include -O2 -mieee -I/usr/include '
-                             '-I/usr/pkg/include -O2 -mieee -I/usr/include '
-                             '-I/usr/pkg/include -std=gnu99 -Wextra '
-                             '-Wno-unused-result -Wno-unused-parameter '
+ 'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
+                             '-I/usr/include -I/usr/pkg/include -O2 '
+                             '-I/usr/include -I/usr/pkg/include -O2 '
+                             '-I/usr/include -I/usr/pkg/include -std=gnu99 '
+                             '-Wextra -Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
                              '-I./Include -I/usr/include -I/usr/pkg/include '
                              '-I/usr/include -I/usr/pkg/include -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -mieee -DNDEBUG -O2 -mieee '
-              '-I/usr/include -I/usr/pkg/include -O2 -mieee -I/usr/include '
-              '-I/usr/pkg/include -O2 -mieee -I/usr/include -I/usr/pkg/include',
+ 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -I/usr/include '
+              '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include -O2 '
+              '-I/usr/include -I/usr/pkg/include',
  'PY_CFLAGS_NODIST': '-std=gnu99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -mieee -DNDEBUG -O2 '
-                   '-mieee -I/usr/include -I/usr/pkg/include -O2 -mieee '
-                   '-I/usr/include -I/usr/pkg/include -O2 -mieee '
-                   '-I/usr/include -I/usr/pkg/include -std=gnu99 -Wextra '
-                   '-Wno-unused-result -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers '
+ 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
+                   '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
+                   '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include '
+                   '-std=gnu99 -Wextra -Wno-unused-result '
+                   '-Wno-unused-parameter -Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include -I/usr/include '
                    '-I/usr/pkg/include -I/usr/include -I/usr/pkg/include -fPIC '
@@ -709,10 +706,10 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_LDFLAGS_NODIST': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -mieee -DNDEBUG -O2 '
-                        '-mieee -I/usr/include -I/usr/pkg/include -O2 -mieee '
-                        '-I/usr/include -I/usr/pkg/include -O2 -mieee '
-                        '-I/usr/include -I/usr/pkg/include -std=gnu99 -Wextra '
+ 'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
+                        '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
+                        '-I/usr/pkg/include -O2 -I/usr/include '
+                        '-I/usr/pkg/include -std=gnu99 -Wextra '
                         '-Wno-unused-result -Wno-unused-parameter '
                         '-Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration '
@@ -727,7 +724,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python310/work.alpha/Python-3.10.14',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python310/work.sparc/Python-3.10.15',
  'SCRIPTDIR': '/usr/pkg/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SHELL': '/bin/sh',
@@ -740,18 +737,18 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_FLOAT': 4,
  'SIZEOF_FPOS_T': 264,
  'SIZEOF_INT': 4,
- 'SIZEOF_LONG': 8,
+ 'SIZEOF_LONG': 4,
  'SIZEOF_LONG_DOUBLE': 8,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
  'SIZEOF_PTHREAD_KEY_T': 4,
- 'SIZEOF_PTHREAD_T': 8,
+ 'SIZEOF_PTHREAD_T': 4,
  'SIZEOF_SHORT': 2,
- 'SIZEOF_SIZE_T': 8,
+ 'SIZEOF_SIZE_T': 4,
  'SIZEOF_TIME_T': 8,
- 'SIZEOF_UINTPTR_T': 8,
- 'SIZEOF_VOID_P': 8,
+ 'SIZEOF_UINTPTR_T': 4,
+ 'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-310',
@@ -769,10 +766,10 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python310/work.alpha/Python-3.10.14 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python310/work.sparc/Python-3.10.15 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python310/work.alpha/Python-3.10.14 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python310/work.sparc/Python-3.10.15 '
                './python ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
@@ -800,8 +797,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/tmp/pkgbuild/lang/python310/work.alpha/Python-3.10.14',
- 'abs_srcdir': '/tmp/pkgbuild/lang/python310/work.alpha/Python-3.10.14',
+ 'abs_builddir': '/tmp/pkgbuild/lang/python310/work.sparc/Python-3.10.15',
+ 'abs_srcdir': '/tmp/pkgbuild/lang/python310/work.sparc/Python-3.10.15',
  'datarootdir': '/usr/pkg/share',
  'exec_prefix': '/usr/pkg',
  'prefix': '/usr/pkg',
